Differential Geometry Module
============================

.. module:: sympy.diffgeom

Introduction
------------

Base Class Reference
--------------------
.. autoclass:: Manifold
   :members:

.. autoclass:: Patch
   :members:

.. autoclass:: CoordSystem
   :members:

.. autoclass:: BaseScalarField
   :members:

.. autoclass:: BaseVectorField
   :members:

.. autoclass:: Differential
   :members:

.. autoclass:: BaseCovarDerivativeOp
   :members:

.. autoclass:: CovarDerivativeOp
   :members:

